/* fake_utsname.o
 *
 * author: hackbard@hackdaworld.dyndns.org
 *
 */

/* what for:
 *
 * fake the machine type discovered by "uname -m" call.
 * this is possibly needed by some crossbuilds, where packages try to determine
 * the host or target architecture with the help of uname output.
 *
 * usage:
 *
 * insmod fake_utsname.o mname="<machine_type>"
 * where <machine_type> could be:
 * sparc64
 * i386
 * etc ...
 */

#include <linux/kernel.h>
#include <linux/module.h>
#include <linux/utsname.h>
#include <linux/string.h>

#define UTSNAME_M_LEN 65

/* if there is no define ... */
#ifndef FAKE_M_UTSNAME
#define FAKE_M_UTSNAME "sparc64"
#endif

MODULE_LICENSE("GPL v2");

char mname_orig[UTSNAME_M_LEN];
char *mname=FAKE_M_UTSNAME;

MODULE_PARM(mname,"s");

int init_module(void) {
 int i;

 memset(mname_orig,0,UTSNAME_M_LEN);
 memcpy(mname_orig,system_utsname.machine,sizeof(system_utsname.machine));
 i=strlen(mname);
 memcpy(system_utsname.machine,mname,i);
 memset(system_utsname.machine+i,0,UTSNAME_M_LEN-i);

 return(0);
}

void cleanup_module(void) {

 memcpy(system_utsname.machine,mname_orig,UTSNAME_M_LEN);

}
